elephant.asset.asset.synchronous\_events\_contained\_in
=======================================================

.. currentmodule:: elephant.asset.asset

.. autofunction:: synchronous_events_contained_in